Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(468)

Unified Diff: components/password_manager/core/browser/password_form_manager.h

Issue 870513002: [PasswordManager] Improve detection of ignorable change password forms. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Incorporated reviews. Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/password_form_manager.h
diff --git a/components/password_manager/core/browser/password_form_manager.h b/components/password_manager/core/browser/password_form_manager.h
index 9256b35331ccafc6218a82243cb4bae4db296db3..91f53a454a84ff2daea247f5610f7b24201c6c3e 100644
--- a/components/password_manager/core/browser/password_form_manager.h
+++ b/components/password_manager/core/browser/password_form_manager.h
@@ -86,13 +86,16 @@ class PasswordFormManager : public PasswordStoreConsumer {
// Returns true if the observed form has both the current and new password
// fields, and the username field was not explicitly marked with
- // autocomplete=username. In these cases it is not clear whether the username
- // field is the right guess (often such change password forms do not contain
- // the username at all), and the user should not be bothered with saving a
- // potentially malformed credential. Once we handle change password forms
- // correctly, or http://crbug.com/448351 gets implemented, this method should
- // be replaced accordingly.
- bool IsIgnorableChangePasswordForm() const;
+ // "autocomplete=username" and the user-typed username and current password
+ // field values do not match the credentials already stored. In these cases it
+ // is not clear whether the username field is the right guess (often such
+ // change password forms do not contain the username at all), and the user
+ // should not be bothered with saving a potentially malformed credential. Once
+ // we handle change password forms correctly, this method should be replaced
+ // accordingly.
+ bool IsIgnorableChangePasswordForm(
+ const base::string16& typed_username,
+ const base::string16& typed_password) const;
// Determines if the user opted to 'never remember' passwords for this form.
bool IsBlacklisted() const;

Powered by Google App Engine
This is Rietveld 408576698